==> wxWidgets-2.8.3.tar.bz2: wxWidgets-2.8.3/include/wx/motif/gauge.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        wx/motif/gauge.h
// Purpose:     wxGauge class
// Author:      Julian Smart
// Modified by:
// Created:     17/09/98
// RCS-ID:      $Id: gauge.h,v 1.15 2006/07/25 14:31:54 ABX Exp $
// Copyright:   (c) Julian Smart
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#ifndef _WX_GAUGE_H_
#define _WX_GAUGE_H_

// Group box
class WXDLLEXPORT wxGauge : public wxGaugeBase
{
    DECLARE_DYNAMIC_CLASS(wxGauge)

public:
    inline wxGauge() { m_rangeMax = 0; m_gaugePos = 0; }

    inline wxGauge(wxWindow *parent, wxWindowID id,
        int range,
        const wxPoint& pos = wxDefaultPosition,
        const wxSize& size = wxDefaultSize,
        long style = wxGA_HORIZONTAL,
        const wxValidator& validator = wxDefaultValidator,
        const wxString& name = wxGaugeNameStr)
    {
        Create(parent, id, range, pos, size, style, validator, name);
    }

    bool Create(wxWindow *parent, wxWindowID id,
        int range,
        const wxPoint& pos = wxDefaultPosition,
        const wxSize& size = wxDefaultSize,
        long style = wxGA_HORIZONTAL,
        const wxValidator& validator = wxDefaultValidator,
        const wxString& name = wxGaugeNameStr);

    void SetShadowWidth(int w);
    void SetRange(int r);
    void SetValue(int pos);

    int GetShadowWidth() const ;
    int GetRange() const ;
    int GetValue() const ;

    virtual void Command(wxCommandEvent& WXUNUSED(event)) {} ;

private:
    virtual wxSize DoGetBestSize() const;
    virtual void DoMoveWindow(int x, int y, int width, int height);
};

#endif
// _WX_GAUGE_H_

==> wxWidgets-3.1.0.tar.bz2: wxWidgets-3.1.0/include/wx/motif/gauge.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        wx/motif/gauge.h
// Purpose:     wxGauge class
// Author:      Julian Smart
// Modified by:
// Created:     17/09/98
// Copyright:   (c) Julian Smart
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#ifndef _WX_GAUGE_H_
#define _WX_GAUGE_H_

// Group box
class WXDLLIMPEXP_CORE wxGauge : public wxGaugeBase
{
    wxDECLARE_DYNAMIC_CLASS(wxGauge);

public:
    inline wxGauge() { m_rangeMax = 0; m_gaugePos = 0; }

    inline wxGauge(wxWindow *parent, wxWindowID id,
        int range,
        const wxPoint& pos = wxDefaultPosition,
        const wxSize& size = wxDefaultSize,
        long style = wxGA_HORIZONTAL,
        const wxValidator& validator = wxDefaultValidator,
        const wxString& name = wxGaugeNameStr)
    {
        Create(parent, id, range, pos, size, style, validator, name);
    }

    bool Create(wxWindow *parent, wxWindowID id,
        int range,
        const wxPoint& pos = wxDefaultPosition,
        const wxSize& size = wxDefaultSize,
        long style = wxGA_HORIZONTAL,
        const wxValidator& validator = wxDefaultValidator,
        const wxString& name = wxGaugeNameStr);

    void SetRange(int r);
    void SetValue(int pos);

    int GetRange() const ;
    int GetValue() const ;

    virtual void Command(wxCommandEvent& WXUNUSED(event)) {} ;

private:
    virtual wxSize DoGetBestSize() const;
    virtual void DoMoveWindow(int x, int y, int width, int height);
};

#endif
// _WX_GAUGE_H_
